Stan Math Library: stan/math/prim/arr/err/check_nonzero_size.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

check_nonzero_size.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_ERR_CHECK_NONZERO_SIZE_HPP
2 #define STAN_MATH_PRIM_SCAL_ERR_CHECK_NONZERO_SIZE_HPP
3
4 #include <stan/math/prim/scal/err/invalid_argument.hpp>
5 #include <string>
6
7 namespace stan {
8
9 namespace math {
10
29 template <typename T_y>
30 inline bool check_nonzero_size(const char* function,
31 const char* name,
32 const T_y& y) {
33 if (y.size() > 0)
34 return true;
35
36 invalid_argument(function, name, 0,
37 "has size ",
38 ", but must have a non-zero size");
39 return false;
40 }
41
42 }
43 }
44 #endif
stan
Definition: log_sum_exp.hpp:8
invalid_argument.hpp
stan::math::check_nonzero_size
bool check_nonzero_size(const char *function, const char *name, const T_y &y)
Return true if the specified matrix/vector is of non-zero size.
Definition: check_nonzero_size.hpp:30
stan::math::invalid_argument
void invalid_argument(const char *function, const char *name, const T &y, const char *msg1, const char *msg2)
Throw an invalid_argument exception with a consistently formatted message.
Definition: invalid_argument.hpp:31

[ Stan Home Page ] © 2011–2016, Stan Development Team.